Name:		compiler-rt
Version:	3.9.1
Release:	%mkrel 4
Summary:	LLVM "compiler-rt" runtime libraries
Group:		Development/Other

License:	NCSA or MIT
URL:		http://llvm.org
Source0:	http://llvm.org/releases/%{version}/%{name}-%{version}.src.tar.xz

# Arm code has some >= v6 ASM
# upstream dont want to support it
ExcludeArch:	armv5tl

BuildRequires:	cmake
BuildRequires:	python
BuildRequires:  llvm-devel >= %{version}-5
BuildRequires:  llvm-static >= %{version}-5

%description
The compiler-rt project is a part of the LLVM project. It provides
implementation of the low-level target-specific hooks required by
code generation, sanitizer runtimes and profiling library for code
instrumentation, and Blocks C language extension.

%prep
%setup -q -n %{name}-%{version}.src

%build
# FC compatibility:
ln -sf build _build
%cmake .. \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DLLVM_CONFIG_PATH:FILEPATH=%{_bindir}/llvm-config \
%if 0%{?__isa_bits} == 64
        -DLLVM_LIBDIR_SUFFIX=64 \
%else
        -DLLVM_LIBDIR_SUFFIX= \
%endif
	-DCOMPILER_RT_INCLUDE_TESTS:BOOL=OFF # could be on?

%make

%install
cd _build
make install DESTDIR=%{buildroot}

# move sanitizer lists to better place
mkdir -p %{buildroot}%{_libdir}/clang/%{version}
for file in asan_blacklist.txt msan_blacklist.txt dfsan_blacklist.txt cfi_blacklist.txt dfsan_abilist.txt; do
	mv -v %{buildroot}%{_prefix}/${file} %{buildroot}%{_libdir}/clang/%{version}/ || :
done

# move sanitizer libs to better place
mkdir -p %{buildroot}%{_libdir}/clang/%{version}/lib
mv -v %{buildroot}%{_prefix}/lib/linux/libclang_rt* %{buildroot}%{_libdir}/clang/%{version}/lib
mkdir -p %{buildroot}%{_libdir}/clang/%{version}/lib/linux/
pushd %{buildroot}%{_libdir}/clang/%{version}/lib
for i in *.a *.syms *.so; do
	ln -s ../$i linux/$i
done

%check
cd _build
#make check-all

%files
%{_includedir}/*
%{_libdir}/clang/%{version}



%changelog
* Tue Mar 28 2017 tmb <tmb> 3.9.1-4.mga6
+ Revision: 1095073
- dont try to build on armv5tl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-3.mga6
+ Revision: 1095068
- try to build on armv5tl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-2.mga6
+ Revision: 1095061
- rebuild with new llvm

* Sat Jan 07 2017 ghibo <ghibo> 3.9.1-1.mga6
+ Revision: 1080450
- Update to release 3.9.1

* Sat Dec 03 2016 pterjan <pterjan> 3.8.1-3.mga6
+ Revision: 1071813
- Exclude armv5tl

* Tue Oct 04 2016 tv <tv> 3.8.1-2.mga6
+ Revision: 1058313
- make symlinks to where the linker thinks these libs are (mga#19510)

* Thu Jul 14 2016 tmb <tmb> 3.8.1-1.mga6
+ Revision: 1042078
- update to 3.8.1 (maintenance release)

* Mon Mar 14 2016 tv <tv> 3.8.0-2.mga6
+ Revision: 990521
- submit to core/release

* Wed Mar 09 2016 tv <tv> 3.8.0-1.mga6
+ Revision: 988412
- new release
- imported package compiler-rt


* Tue Mar 08 2016 Thierry Vignaud <tv@mageia.org> 3.8.0-1.mga6
- compiler-rt 3.8.0rc3

* Thu Feb 18 2016 Dave Airlie <airlied@redhat.com> - 3.8.0-0.1
- compiler-rt 3.8.0rc2

* Fri Feb 05 2016 Dave Airlie <airlied@redhat.com> 3.7.1-3
- fix compiler-rt paths - from rwindz0@gmail.com - #1304605

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Oct 06 2015 Jan Vcelak <jvcelak@fedoraproject.org> 3.7.0-100
- initial version using cmake build system
